@@ -81,6 +81,14 @@ class K3SController:
         self._check_error(response.status_code, info)
         return info
 
+    @exception_class_dec(max_try=1)
+    def cordon(self, node_name:str, timeout=3):
+        response = requests.get(f'{self.url}/node/cordon/node_name/{node_name}', 
+            headers=self.header, timeout=timeout)
+        succeed = json.loads(response.text)
+        self._check_error(response.status_code, succeed)
+        return succeed
+
     @exception_class_dec(max_try=1)
     def get_instance_info_by_node_meta(self, region_id: str, node_meta: NodeMetaDO, timeout=300):
         data = json.dumps(node_meta.dict())
