@@ -163,9 +163,9 @@ class PodOSSOperationInfoDO(BaseDO):
 class NodeMetaDO(BaseModel):
     name: str
     status: str
-    run_time: str
+    run_time: Union[str, datetime.timedelta]
     k3s_version: str
-    label: str
+    label: Union[str, Dict]
     private_ip: str
     _life_time: int=5
 
